/*
 * A tool to program the FPGA within the SPEC.
 *
 * Alessandro Rubini 2012 for CERN, GPLv2 or later.
 */

#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <getopt.h>

#include "sveclib.h"

int main(int argc, char **argv)
{
	int bus = -1,  c, do_write = 0;
	uint32_t addr, data;
	void *card;
	int is_csr = 0;

	while ((c = getopt (argc, argv, "b:c")) != -1)
	{
		switch(c)
		{
		case 'b':
			sscanf(optarg, "%i", &bus);
			break;

		case 'c':
			is_csr= 1;
			break;
		default:
			fprintf(stderr,
				"Use: \"%s [-c] -b slot addr [data]\"\n", argv[0]);
			exit(1);
		}
	}

	if(bus < 0)
	{
	    fprintf(stderr, "You must specify the slot number.\n");
	    return -1;
	}

	if(optind >= argc)	
	{
		fprintf(stderr, "Address expected.\n");
		return -1;
	}
    
	sscanf(argv[optind++], "%i", &addr);

	if(optind < argc)	
	{
		sscanf(argv[optind], "%i", &data);
		do_write = 1;
	}
    
        card = svec_open(bus);

	if(!card)
	{
	 	fprintf(stderr, "Can't detect a SVEC card under the given adress. Make sure a SVEC card is present in your PC and the driver is loaded.\n");
	 	exit(1);
	}

	if(do_write)
	    svec_writel(card, data, addr);
	else
	    printf("%08x\n", svec_readl(card, addr));
	

	svec_close(card);
	
	return 0;
}
